Crate multipart_rfc7578

This crate contains an implementation of the multipart/form-data media type described in RFC 7578.

Usage

[dependencies]
multipart-rfc7578 = "0.7"

use multipart_rfc7578::Form;

let mut form = Form::default();

form.add_text("test", "Hello World");

Structs

  • Multipart body that is compatible with Hyper and Actix-web.
  • Implements the multipart/form-data media type as described by RFC 7578.

Traits

  • A BoundaryGenerator is a policy to generate a random string to use as a part boundary.