Structs
- Multipart body that is compatible with Hyper and Actix-web.
- Implements the multipart/form-data media type as described by RFC 7578.
Traits
- A
BoundaryGeneratoris a policy to generate a random string to use as a part boundary.